aboutsummaryrefslogtreecommitdiff
path: root/emms-default.el
diff options
context:
space:
mode:
authorlucas <lucas>2005-09-18 12:51:00 +0000
committerlucas <mwolson@gnu.org>2005-09-18 12:51:00 +0000
commit24d8b5142333d50e6dfc4d908fffb06cd5bfd7b1 (patch)
treef9aab49f24d0f0f94ba36e3267b8c449f8c0044a /emms-default.el
parent549de334b204dbc9ba96277a0c46c9a40468c12c (diff)
Making emms-default now emms-playlist-mode compatible
darcs-hash:20050918125105-4f952-230ff24b0e2c179270762b82c0c18db144d4c1dd.gz
Diffstat (limited to 'emms-default.el')
-rw-r--r--emms-default.el21
1 files changed, 7 insertions, 14 deletions
diff --git a/emms-default.el b/emms-default.el
index 74112db..17d10b8 100644
--- a/emms-default.el
+++ b/emms-default.el
@@ -44,9 +44,9 @@ of the version you have installed.
All possible values for the LEVEL, are:
`cvs' -- Everything and no guarantees
-`advanced' -- info, pbi, tageditor
+`advanced' -- info, playlist-mode, tageditor
`default' -- info and the playlist-buffer-interface.
-`tiny' -- basic and pbi
+`tiny' -- basic and playlist-mode
`minimalistic' -- No bells and whistles, no info, no interfaces. M-x
emms-next RET and such, as well as a single player. This should almost
always work, unless you get very unlucky with a CVS-build."
@@ -64,10 +64,11 @@ always work, unless you get very unlucky with a CVS-build."
(ding))
(unless (equal level 'minimalistic) ; tiny
- (require 'emms-pbi)
+ (require 'emms-playlist-mode)
+ (setq emms-playlist-default-major-mode 'emms-playlist-mode)
(unless (equal level 'tiny) ; default
;; must be default, advanced or cvs, include the pbi and the info
(require 'emms-info)
(require 'emms-info-mp3info)
(setq emms-info-methods-list '(emms-info-mp3info))
@@ -82,18 +83,10 @@ always work, unless you get very unlucky with a CVS-build."
(unless (equal level 'default) ; advanced
;; + tageditor.
- (require 'emms-tageditor)
- (emms-tageditor-pbi-mode 1)
-
- ;; and pl-manip
- (require 'emms-pl-manip)
+ ;;(require 'emms-tageditor)
+ ;;(emms-tageditor-pbi-mode 1)
(unless (equal level 'advanced) ; cvs
- (require 'emms-pbi-mark)
- (emms-pbi-mark 1)
- (emms-tageditor-pbi-mark-mode 1)
- (require 'emms-pbi-popup)
-
;; load the mode-line
(require 'emms-mode-line)
(emms-mode-line 1)
@@ -64,10 +64,11 @@ always work, unless you get very unlucky with a CVS-build."
(unless (equal level 'tiny) ; default
- ;; must be default, advanced or cvs, include the pbi and the info
+ ;; must be default, advanced or cvs, include the playlist-mode and the info
(require 'emms-info)
(require 'emms-info-mp3info)